@@ -2,7 +2,7 @@ use strict 'vars', 'subs';
                                                                                                                                    # $VERSION information.
 
 package DBIx::Squirrel;
-$DBIx::Squirrel::VERSION = '1.2.2'; # TRIAL
+$DBIx::Squirrel::VERSION = '1.2.3'; # TRIAL
 use warnings;
 use constant E_BAD_ENT_BIND     => 'Cannot associate with an invalid object';
 use constant E_EXP_HASH_ARR_REF => 'Expected a reference to a HASH or ARRAY';
@@ -13,35 +13,38 @@ use constant E_EXP_HASH_ARR_REF => 'Expected a reference to a HASH or ARRAY';
 
 =head1 NAME
 
-DBIx::Squirrel - A module for working with databases
+DBIx::Squirrel - A C<DBI> extension
 
 =head1 VERSION
 
-version 1.2.2
+version 1.2.3
 
 =head1 SYNOPSIS
 
-    # Simply use the package.
+    # Use DBIx::Squirrel just like DBI...
 
     use DBIx::Squirrel;
 
     $dbh = DBIx::Squirrel->connect($dsn, $user, $pass, \%attr);
-    $sth = $dbh->prepare('SELECT * FROM product WHERE id = ?');
-    $res = $sth->execute('1001099');
-    $itr = $sth->iterate('1001099');
-    while ($row = $itr->next) {...}
+    $sth = $dbh->prepare('SELECT * FROM product WHERE Name=?');
 
-    # Or, use it and have it create and import helper functions that
-    # you can use to interact with database objects.
+    if ( $sth->execute('Acme Rocket') ) {
+        $row = $sth->fetchrow_hashref
+        say "$row->{'Name'}";
+        $sth->finish
+    }
 
-    use DBIx::Squirrel database_objects=>['db', 'st', 'it'];
+    # Or, take advantage of the convenient extras that DBIx::Squirrel
+    # offers...
 
-    db DBIx::Squirrel->connect($dsn, $user, $pass, \%attr);
-    st db->prepare('SELECT * FROM product WHERE id = ?');
-    $res = st->execute('1001099');
-    $res = st('1001099');  # Same as line above.
-    it st->iterate('1001099');
-    while ($row = it->next) {...}
+    use DBIx::Squirrel database_objects=>['db', 'product'];
+
+    db do { DBIx::Squirrel->connect($dsn, $user, $pass, \%attr) };
+    product do { db->results('SELECT * FROM product WHERE Name=:Name') };
+
+    if ( $row = product( Name => 'Acme Rocket' )->single ) {
+        say $row->Name;
+    }
 
     # Clone another database connection.
 
@@ -222,13 +225,11 @@ use DBIx::Squirrel::rc ();
 use DBIx::Squirrel::util 'throw';
 
 BEGIN {
-    *EXPORT_OK   = *DBI::EXPORT_OK;
-    *EXPORT_TAGS = *DBI::EXPORT_TAGS;
-    *err         = *DBI::err;
-    *errstr      = *DBI::errstr;
-    *rows        = *DBI::rows;
-    *lasth       = *DBI::lasth;
-    *state       = *DBI::state;
+    our @ISA                          = ('DBI');
+    our $FINISH_ACTIVE_BEFORE_EXECUTE = 1;
+    our $NORMALISE_SQL                = 1;
+
+    *NORMALIZE_SQL = *NORMALISE_SQL;
 
     *connect         = *DBIx::Squirrel::dr::connect;
     *connect_cached  = *DBIx::Squirrel::dr::connect_cached;
@@ -238,18 +239,24 @@ BEGIN {
     *BUF_MULT        = *DBIx::Squirrel::it::BUF_MULT;
     *BUF_MAXROWS     = *DBIx::Squirrel::it::BUF_MAXROWS;
 
-    our @ISA                   = ('DBI');
-    our $STRICT_PARAM_CHECKING = 0;
-    our $AUTO_FINISH_ON_ACTIVE = 1;
-    our $NORMALISE_SQL         = 1;
-    *NORMALIZE_SQL = *NORMALISE_SQL;
+    *EXPORT_OK   = *DBI::EXPORT_OK;
+    *EXPORT_TAGS = *DBI::EXPORT_TAGS;
+    *err         = *DBI::err;
+    *errstr      = *DBI::errstr;
+    *rows        = *DBI::rows;
+    *lasth       = *DBI::lasth;
+    *state       = *DBI::state;
 }
 
 sub import {
     my $class  = shift;
     my $caller = caller;
 
+    # Partition import list into lists of helper function names and
+    # DBI imports.
+
     my ( @helpers, @dbi_imports );
+
     while (@_) {
         if ( $_[0] =~ m/^database_objects?$/i ) {
             shift;
@@ -273,6 +280,8 @@ sub import {
     my %seen;
     @helpers = grep { !$seen{$_}++ } @helpers;
 
+    # Create (if necessary) and export helpers.
+
     for my $name (@helpers) {
         my $symbol = $class . '::' . $name;
         my $helper = sub {
@@ -298,7 +307,6 @@ sub import {
 
             return unless defined ${$symbol};
 
-
             # At this point, we have an association. If we have arguments then
             # we are addressing the associated database object, and they are
             # passed to the object's relevant method for processing.
@@ -354,10 +362,13 @@ sub import {
         # Then export them to the caller!
 
         @_ = ( 'DBIx::Squirrel', @dbi_imports );
+
+        # Jump-jump, sugar lump, we don't want a new stack frame!
+
         goto &Exporter::import;
-    } else {
-        return $class;
     }
+
+    return $class;
 }
 
 1;
@@ -439,7 +450,7 @@ Meaning in this context is determined by the type of association:
 
 =over
 
-=item * 
+=item *
 
 for a database connection, a statement is prepared using the C<prepare> method;
 
@@ -509,8 +520,10 @@ to dip a toe in the water ahead of time:
 Connecting to a database using C<DBIx::Squirrel> may be done exactly as it
 would when using the C<DBI>'s C<connect_cached> and C<connect> methods.
 
-The C<connect> method implemented by the C<DBIx::Squirrel> package does,
-however, offer an alternative form:
+=head3 Cloning database connections
+
+The C<connect> method implemented by the C<DBIx::Squirrel> package offers
+an alternative form:
 
     $new_dbh = DBIx::Squirrel->connect($original_dbh, \%attr);
 
@@ -525,9 +538,11 @@ Preparing a statement using C<DBIx::Squirrel> may be done exactly as
 it would be done using the C<DBI>'s C<prepare_cached> and C<prepare>
 methods.
 
-One nice quality-of-life feature offered by C<DBIx::Squirrel>'s own
-implementation of the C<prepare_cached> and C<prepare> methods is
-its built-in support for a variety of placeholder styles:
+=head3 Placeholders
+
+A nice quality-of-life improvement offered by C<DBIx::Squirrel>'s own
+implementation of the C<prepare_cached> and C<prepare> methods is the
+built-in support for different placeholder styles:
 
 =over
 
@@ -539,11 +554,11 @@ its built-in support for a variety of placeholder styles:
 
 =back
 
-Regardless of your C<DBD> driver or your preferred style, statements
+Regardless of your C<DBD> driver, or your preferred style, statements
 will be normalised to the legacy placeholder (C<?>) by the time they
 are executed.
 
-Use your preferred style or the style that most helps your query to
+Use your preferred style, or the style that most helps your query to
 be reasoned by others.
 
 =head4 Examples
@@ -555,61 +570,63 @@ be reasoned by others.
 Legacy placeholders (C<?>):
 
     $sth = $dbh->prepare('SELECT * FROM artists WHERE Name=? LIMIT 1');
+
+    # Any of the following value-binding styles will work:
     $res = $sth->execute('Aerosmith');
+    $res = $sth->execute([ 'Aerosmith' ]);
 
 =item *
 
 SQLite positional placeholders (C<?number>):
 
     $sth = $dbh->prepare('SELECT * FROM artists WHERE Name=?1 LIMIT 1');
+
+    # Any of the following value-binding styles will work:
     $res = $sth->execute('Aerosmith');
+    $res = $sth->execute([ 'Aerosmith' ]);
 
 =item *
 
 PostgreSQL positional placeholders (C<$number>):
 
     $sth = $dbh->prepare('SELECT * FROM artists WHERE Name=$1 LIMIT 1');
+
+    # Any of the following value-binding styles will work:
     $res = $sth->execute('Aerosmith');
+    $res = $sth->execute([ 'Aerosmith' ]);
 
 =item *
 
 Oracle positional placeholders (C<:number>):
 
     $sth = $dbh->prepare('SELECT * FROM artists WHERE Name=:1 LIMIT 1');
+
+    # Any of the following value-binding styles will work:
     $res = $sth->execute('Aerosmith');
+    $res = $sth->execute([ 'Aerosmith' ]);
 
 =item *
 
 Oracle named placeholders (C<:number>):
 
     $sth = $dbh->prepare('SELECT * FROM artists WHERE Name=:Name LIMIT 1');
-    $res = $sth->execute(Name => 'Aerosmith');
 
-=back 
-
-=head2 Results processing
-
-=over
-
-=item *
-
-A C<DBIx::Squirrel> statement can produce two kinds of iterator, to
-provide for efficient processing of results. These are generated using
-statement's C<iterate> and C<results> methods in place of C<execute>.
-
-=item *
-
-Iterators offer a declarative way to process results using callbacks
-chains to transform results before they are returned to the caller.
-
-=item *
-
-Some DBIx-Squirrel iterator methods named C<all>, C<find>, C<first>,
-C<next>, C<single> may already be familiar to C<DBIx::Class>
-users, and they do similar jobs.
+    # Any of the following value-binding styles will work:
+    $res = $sth->execute( Name => 'Aerosmith' );
+    $res = $sth->execute({ Name => 'Aerosmith' });
+    $res = $sth->execute( ':Name' => 'Aerosmith' );
+    $res = $sth->execute({ ':Name' => 'Aerosmith' });
 
 =back
 
+=head2 Iterators
+
+(TO DO)
+
+=head2 Processing results
+
+(TO DO)
+
 =head1 COPYRIGHT AND LICENSE
 
 The DBIx::Squirrel module is Copyright (c) 2020-2014 Iain Campbell.
